@@ -7,11 +7,13 @@
 #
 
 # kinematics
-g = 9.81 # 重力加速度 m/s**2
-g_acceralation = g # 重力加速度 m/s**2
+g0 = 9.81 # 重力加速度 m/s**2
+g = g0
+g_acceralation = g0 # 重力加速度 m/s**2
 Re = 6371.229 * 1000 # m
 P0 = 100000 # Pa
 PI = 3.141592653589793
+Omega = 7.2921159 * 1E5
 
 # thermodynamics
 sat_pressure_0c = 611.2 # units : Pa
@@ -24,5 +26,6 @@ f0 = 1E-4
 GammaD = g/Cp
 Kelvin = 273.15
 Tabs = Kelvin
+GasC = R
 
 
